setwd("C:/Users/sully/Box/Koski Lab/Cierra_FlowerColor_herbarium/Working Spreadsheets")
library(MASS)
library(MuMIn)
library(foreign)
library(nnet)
library(lmerTest)
library(multcomp)
library(car)
library(readxl)
library(logistf)
library(QuantPsyc)

#### Setup of Data ####
merge <- read_excel("./Merged.data.xlsx", sheet = "Merged.data")
merge$PPT <- as.numeric(merge$PPT)
merge$VPDMIN <- as.numeric(merge$VPDMIN)
merge$VPDMAX <- as.numeric(merge$VPDMAX)
merge$TMIN <- as.numeric(merge$TMIN)
merge$TMAX <- as.numeric(merge$TMAX)
merge$TDMEAN <- as.numeric(merge$TDMEAN)
merge$TMEAN <- as.numeric(merge$TMEAN)
merge$logalt <- log(20+merge$alt)

#### Spatiotemporal model with Nested Month ####

factors<-cbind(merge[c(4:5, 23, 35)])
factors<-scale(factors, center=TRUE, scale=TRUE)
scaleds <-cbind(merge[c(6:12, 20, 22, 34, 1)],factors)

a5 <- glm(ncm ~ sp*lat.x*lon.x + sp*lat.x*logalt + sp*lon.x*logalt + lat.x*lon.x*logalt +sp*year*logalt + sp*year*lat.x +sp*year*lon.x +month + month%in%year, family = 'binomial', data=scaleds)
Anova(a5, type= 3)

#### Climatic Model ####
cor <- cor(merge[6:12], use = "complete.obs") ##Add use function so R will "count" the 0's! "pairwise.complete.obs" is another one, and more
cor

##VPDMAX & TMAX r = 0.801 VPDMIN & VPDMAX r = 0.683 VPDMAX $ TMEAN r = 0.606 TMIN & TMAX r = 0.784
##TMIN & TDMEAN r = 0.826 TMIN & TMEAN r = 0.945 TMAX & TMEAN  r = 0.944 TDMEAN & TMEAN r = 0.708

#SCALED
factors2<-cbind(merge[c(6:12)])
factors2<-scale(factors2, center=TRUE, scale=TRUE)
merge.sc <-cbind(merge[c(34, 1, 20, 23)],factors2)

win <- glm(ncm ~ SP+PPT+TMIN+VPDMAX+sp, family='binomial', data = merge.sc)
Anova(win, type = 3)

#### Looping Code to obtain year effects on pigmentation, PPT, TMIN and VPDMAX#### 

spl.evy <- with(scaleds, split(scaleds, list(sp=sp)))

coefGLM.ncm <- function(x) {
  coef(glm(ncm ~ lat.x+lon.x+logalt+month+year+(month %in% year), data = x, family = "binomial"))
}

coefs.ncm <- sapply(spl.evy, coefGLM.ncm)
coefs.ncm

coefGLM.ppt <- function(x) {
  coef(glm(PPT ~ lat.x+lon.x+logalt+month+year+(month %in% year), data = x))[6]
}

coefs.ppt <- sapply(spl.evy, coefGLM.ppt)
coefs.ppt

coefGLM.tmin <- function(x) {
  coef(glm(TMIN ~ lat.x+lon.x+logalt+month+year+(month %in% year), data = x))[6]
}

coefs.tmin <- sapply(spl.evy, coefGLM.tmin)
coefs.tmin

coefGLM.vpdmax <- function(x) {
  coef(glm(VPDMAX ~ lat.x+lon.x+logalt+month+year+(month %in% year), data = x))[6]
}

coefs.vpdmax <- sapply(spl.evy, coefGLM.vpdmax)
coefs.vpdmax

##summary() to get S.E.
sumGLM.ncm <- function(x) {
  summary(glm(ncm ~ lat.x+lon.x+logalt+month+year+(month %in% year), data = x, family = "binomial"))
}

sum.ncm <- sapply(spl.evy, sumGLM.ncm)
sum.ncm

ssumGLM.ppt <- function(x) {
  summary(glm(PPT ~ lat.x+lon.x+logalt+month+year+(month %in% year), data = x))[6]
}

sum.ppt <- sapply(spl.evy, sumGLM.ppt)
sum.ppt

sumGLM.tmin <- function(x) {
  summary(glm(TMIN ~ lat.x+lon.x+logalt+month+year+(month %in% year), data = x))[6]
}

sum.tmin <- sapply(spl.evy, sumGLM.tmin)
sum.tmin

sumGLM.vpdmax <- function(x) {
  summary(glm(VPDMAX ~ lat.x+lon.x+logalt+month+year+(month %in% year), data = x))[6]
}

sum.vpdmax <- sapply(spl.evy, sumGLM.vpdmax)
sum.vpdmax

#### Firth Regression For taxa with few unpigmented populations ####
## just for A.ceruum, H.matronalis, and L.dianthiflorus
ac <- read_excel("./Merged.data.xlsx", sheet = "A.cernuum")
ac$logalt <- log(20+ac$alt)
facts <- cbind(ac[c(4,5,35,22, 23)])
facts<-scale(facts, center=TRUE, scale=TRUE)
scaled.ac <-cbind(ac[c(20, 34, 1, 6:12)],facts)
ac.model <- logistf(ncm ~ lon.x + lat.x + logalt + month+year + (month %in% year), data = scaled.ac, pl = TRUE, firth = TRUE)
summary(ac.model)

hesp <- read_excel("./Merged.data.xlsx", sheet = "H.matronalis")
hesp$alt <- as.numeric(hesp$alt)
hesp$logalt <- log(20+hesp$alt)
facts2 <- cbind(hesp[c(4,5,35,22, 23)])
facts2<-scale(facts2, center=TRUE, scale=TRUE)
scaled.hesp <-cbind(hesp[c(20, 34, 1, 6:12)],facts2)
hesp.model <- logistf(ncm ~ lon.x + lat.x + logalt + month+year + (month %in% year), data = scaled.hesp, pl = TRUE, firth = TRUE)
summary(hesp.model)

ld <- read_excel("./Merged.data.xlsx", sheet = "L.dianthiflorus")
ld$logalt <- log(20+ld$alt)
facts3 <- cbind(ld[c(4,5,35,22, 23)])
facts3<-scale(facts3, center=TRUE, scale=TRUE)
scaled.ld <-cbind(ld[c(20, 34, 1, 6:12)],facts3)
ld.model <- logistf(ncm ~ lon.x + lat.x + logalt + month+year + (month %in% year), data = scaled.ld, pl = TRUE, firth = TRUE)
summary(ld.model)


#### Climatic change and color change model ####
# with coefficients and S.E. obtained from loops and Firth's
yrmn.coefs <- read_excel("./Month Nested Year.xlsx", sheet = "final")

factors<-cbind(yrmn.coefs[c(3:5)])
factors<-scale(factors, center=TRUE, scale=TRUE)
scaled2 <-cbind(yrmn.coefs[c(1,2,6:14)],factors)

y <- glm(ncm~ppt+tmin+vpdmax,data=scaled2)
summary(y)
#y2 <-glm(ncm~ppt+tmin+vpdmax, weights = scaled2$weight, data = scaled2) #with weights
#summary(y2)

#yb <- glm(ncm ~ ppt*tmin*vpdmax, data = scaled2)
#Anova(yb, type = 3)
#yb2 <- glm(ncm ~ ppt*tmin*vpdmax, data = scaled2, weights = scaled2$weight) #with weights
#Anova(yb2, type = 3)

library(effects)

vpd.effect<-effect('vpdmax', y, residual=TRUE)
plot(vpd.effect, smooth.residuals=FALSE)
tmin.effect<-effect('tmin', y, residual=TRUE)
plot(tmin.effect, smooth.residuals=FALSE)
ppt.effect<-effect('ppt', y, residual=TRUE)
plot(ppt.effect, smooth.residuals=FALSE)


#all.eff <- predictorEffects(y, residuals=TRUE) #plots effect plots of all predictors in mod at once
#plot(all.eff, smooth.residuals=FALSE)

#resid.novpd <- resid(glm(ncm~tmin+ppt, data = yrmn.coefs))
require(ggplot2)
#g1 <- ggplot(yrmn.coefs, aes(x=vpdmax, y = resid.novpd))
 g1 + geom_point() + theme_bw() + theme(panel.grid = element_blank()) + stat_smooth(method = "lm", se=TRUE) + ylim(-2,3)
 